export declare function sstEnv(): Promise<{
    environment: {
        account: string | undefined;
        region: string;
    };
}>;
/**
 * Bootstrap and returns the boostrapped environment. Only returns 1 environment.
 *
 * Used by sst cli.
 *
 * @returns {
 *    environment: { account, region }
 *  }
 */
export declare function sstBootstrap(): Promise<any>;
/**
 * List all stacks with dependencies.
 *
 * Used by deploy workflow.
 *
 * @returns { stacks: [{ id, name, dependencies }] }
 */
export declare function sstList(outputPath: string): Promise<0 | {
    id: string;
    name: string;
    environment: import("@aws-cdk/cx-api").Environment;
}[] | {
    stacks: {
        id: string;
        name: string;
        dependencies: string[];
    }[];
}>;
/**
 * Synth all stacks, and returns synthesized stacks.
 *
 * Used by sst cli.
 *
 * @returns { stacks: [{ id, name }] }
 */
export declare function sstSynth(): Promise<any>;
/**
 * Deploy a single stack exclusively or deploy all stacks, and returns deployed stacks.
 *
 * Used by sst cli.
 *
 * @param stackName the stack to be deploy. All stacks are deployed if not specified.
 *
 * @returns { stacks: [{ id, name }] }
 */
export declare function sstDeploy(stackName?: string): Promise<any>;
/**
 * Destroy a single stack exclusively or destroy all stacks, and returns destroyed stacks.
 *
 * Used by sst cli.
 *
 * @param stackName the stack to be destroyed. All stacks are destroyed if not specified.
 *
 * @returns { stacks: [{ id, name }] }
 */
export declare function sstDestroy(stackName?: string): Promise<any>;
/**
 * Deploy a single stack asynchronously, and returns the environment deployed to and deploy status.
 *
 * Used by deploy workflow.
 *
 * @param outputPath the path to cdk.out folder.
 * @param stackName the stack to be deploy.
 * @param force always deploy stack even if templates are identical.
 *
 * @returns { account, region, status: 'no_resources' | 'unchanged' | 'deploying'  }
 */
export declare function sstDeployAsync(outputPath: string, stackName: string, force: boolean): Promise<any>;
/**
 * Get asynchronous deploy status.
 *
 * Used by deploy workflow.
 *
 * @param outputPath the path to cdk.out folder.
 * @param stackName the stack to be deploy.
 *
 * @returns { status: 'deploying' | 'deployed'  }
 */
export declare function sstDeployStatus(outputPath: string, stackName: string): Promise<{
    status: string;
}>;
/**
 * Destroy a single stack asynchronously, and returns destroy status.
 *
 * Used by deploy workflow.
 *
 * @param outputPath the path to cdk.out folder.
 * @param stackName the stack to be destroy.
 *
 * @returns { account, region, status: 'destroying' | 'destroyed'  }
 */
export declare function sstDestroyAsync(outputPath: string, stackName: string): Promise<any>;
/**
 * Get asynchronous destroy status.
 *
 * Used by deploy workflow.
 *
 * @param outputPath the path to cdk.out folder.
 * @param stackName the stack to be destroyed.
 *
 * @returns { status: 'destroying' | 'destroyed'  }
 */
export declare function sstDestroyStatus(outputPath: string, stackName: string): Promise<{
    status: string;
}>;
